pub fn encode<F: ALPFloat>(
values: &[F],
exponents: Option<Exponents>,
) -> (Exponents, Vec<F::ALPInt>, Vec<u64>, Vec<F>, Vec<u64>)Expand description
Encodes an array of floating-point values, finding the best exponents if they are not provided.
Returns the exponents, the encoded values, the positions and values of the exceptions, and the
offset into the exception positions at which each ENCODE_CHUNK_SIZE chunk begins.